@@ -125,15 +125,22 @@ class LogItemType(BaseModel):
     originator: Optional[str] = Field(default='SYSTEM', description='Zdroj logu', examples=['<NAME>'])
     message: Optional[str] = Field(default=None, description='Zpráva logu', examples=['Autorizováno'])
 
+    def __str__(self):
+        out = f"{self.timestamp.replace(microsecond=0).isoformat(' ')} [{self.originator}] {self.message}"
+        return out
+
 
 class ContainerHistoryItemType(BaseModel):
     # položka historie zařazení do kontejnerů
     timestamp: datetime = Field(default=local_now(), description='Časová značka logu')
     originator: Optional[str] = Field(default='SYSTEM', description='Zdroj logu', examples=['<NAME>'])
-    # container: Optional[UUID] = Field(default=None, description='Identifikátor kontejneru')
     container: Optional[str] = Field(default=None, description='Identifikátor kontejneru')
     message: Optional[str] = Field(default=None, description='Zpráva logu', examples=['Autorizováno'])
 
+    def __str__(self):
+        out = f"{self.timestamp.replace(microsecond=0).isoformat(' ')} [{self.originator}] container={self.container}: {self.message}"
+        return out
+
 
 class AclType(BaseModel):
     name: Optional[str] = Field(
@@ -299,11 +306,12 @@ class LocationType(BaseModel):
     wgs: Optional[GeoPointType] = Field(default=None, description='WGS84')
     jtsk: Optional[GeoPointJtskType] = Field(default=None, description='JTSK')
 
+
 class PersonCoreType(BaseModel):
     ico: Optional[str] = Field(default=None, description='IČO osoby')
     name: Optional[str] = Field(default=None, description='Název osoby', examples=['B.A.R. Reptofilia'])
     email: Optional[EmailStr] = Field(default=None, description='Email osoby')
-    address: Optional[str] = Field(default=None, description='Adresa osoby', examples=['Ulice Závodu Míru 2\n87423 Otrokovice'])
+    address: Optional[str] = Field(default=None, description='Adresa osoby (legacy)', examples=['Ulice Závodu Míru 2\n87423 Otrokovice'])
     country: Optional[CodeValueType] = Field(default=None, description='Země adresy osoby')
 
 class PersonBaseType(PersonCoreType):
@@ -314,6 +322,7 @@ class PersonBaseType(PersonCoreType):
     uuid: Optional[str] = Field(default=None, description='Unique identifier (UUID)')
     person_printable: Optional[str] = Field(default=None, description='Název osoby pro tisk', examples=['B.A.R. Reptofilia'])
     main_person: Optional[LinkedType] = Field(default=None, description='Odkaz na hlavní osobu do registru')
+    location: Optional[LocationType] = Field(default=None, description='Detailní adresa osoby (kompatibilní s CITES Toolkit)')
     linked_persons: Optional[List[Optional[LinkedType]]] = Field(default=None, description='Odkaz na další osoby do registru')
 
     def make_identifier(self) -> Optional[str]:
@@ -331,7 +340,7 @@ class WorkflowType(BaseModel):
     node_name: Optional[str] = Field(default=None, description='Název schvalovacího  uzlu (schválení, autorizace, ...)', examples=['Schválení'])
     responsible: Optional[PersonBaseType] = Field(default=None, description='Odpovědná osoba')
     date_execution: Optional[datetime] = Field(default=local_now(), description='Datum provedení')
-    executor: Optional[UserType] = Field(default='SYSTEM', description='Uživatel, který provedl událost')
+    executor: Optional[UserType] = Field(default=None, description='Uživatel, který provedl událost')
     status_from: Optional[str] = Field(default=None, description='Předchozí stav')
     status_to: Optional[str] = Field(default=None, description='Následný stav')
 
