@@ -357,6 +357,18 @@ def is_valid_pid(value: str) -> bool:
     return bool(re.search(pattern, value))
 
 
+def is_valid_cz_permit_id(value: str) -> bool:
+    """
+    Kontrola validity čísla permitu
+    :param value:
+    :return:
+    """
+    if value is None:
+        return False
+    pattern = r"^\d{2}CZ\d{6}$"
+    return bool(re.match(pattern, value.upper()))
+
+
 def is_valid_ico(ico: str) -> bool:
     """
     Kontrola validity IČO
